@@ -138,16 +138,8 @@ class RedisCustomer(object):
                                         time.sleep(sleep_time if sleep_time > 0 else 0)
                                         current_customer_count = 0
                                         get_queue_begin_time = time.time()
-                            if self.is_support_mutil_param and '{' in message and '}' in message:
-                                message = json.loads(msg)
-                                if type(message) != dict:
-                                    raise Exception('请发布【字典】类型消息,当前消息是【字符串】类型')
                             self._threadpool.submit(self._consuming_exception_retry, msg)
                     else:
-                        if self.is_support_mutil_param and '{' in message and '}' in message:
-                            message = json.loads(message)
-                            if type(message) != dict:
-                                raise Exception('请发布【字典】类型消息,当前消息是【字符串】类型')
                         if self.qps != 0:
                             if self.qps < 5:
                                 sleep_seconds = (1 / self.qps) * self.process_num - get_message_cost if (
@@ -192,7 +184,11 @@ class RedisCustomer(object):
                 if type(message) == dict:
                     self._consuming_function(**message)
                 else:
-                    self._consuming_function(**json.loads(message))
+                    dit_message = json.loads(message)
+                    if type(dit_message) == dict:
+                        self._consuming_function(**dit_message)
+                    else:
+                        self._consuming_function(dit_message)
 
             consuming_exception_retry(message)
             if self.ack:
@@ -378,7 +374,7 @@ class RedisPublish(object):
         return self._redis_quenen.qsize()
 
 
-def task_deco(queue_name, **consumer_init_kwargs):
+def task_deco(queue_name, *consumer_args, **consumer_init_kwargs):
     """
     support by ydf
     装饰器方式添加任务，如果有人过于喜欢装饰器方式，例如celery 装饰器方式的任务注册，觉得黑科技，那就可以使用这个装饰器。此种方式不利于ide代码自动补全不推荐。
@@ -402,7 +398,7 @@ def task_deco(queue_name, **consumer_init_kwargs):
     """
 
     def _deco(func):
-        cs = RedisCustomer(queue_name, consuming_function=func, **consumer_init_kwargs)
+        cs = RedisCustomer(queue_name, consuming_function=func, *consumer_args, **consumer_init_kwargs)
         if 'consuming_function' in consumer_init_kwargs:
             consumer_init_kwargs.pop('consuming_function')
         func.consumer = cs
